@@ -4,4 +4,7 @@ from .nrPBCHDMRS import nrPBCHDMRS
 from .nrCarrierConfig import nrCarrierConfig
 from .nrResourceGrid import nrResourceGrid
 from .nrOFDMModulate import nrOFDMModulate
-from .nrOFDMDemodulate import nrOFDMDemodulate
\ No newline at end of file
+from .nrOFDMDemodulate import nrOFDMDemodulate
+from .nrSSSIndices import nrSSSIndices
+from .nrExtractResources import nrExtractResources
+from .nrPSSIndices import nrPSSIndices
\ No newline at end of file
